@@ -361,7 +361,27 @@ class AGServerHelperNTLM(object):
 
         if not self.__assert_json_success(permisions_data):
             raise MyError.MyError(
-                "Error while setting permisions information for {} to {}.".format(
+                "Error while setting permissions information for {} to {}.".format(
+                    service, principal))
+
+    def removeServicePermisions(self, folder, service, principal):
+        """Add service permisions
+
+        Args:
+            self: The reserved object 'self'
+            folder: Service directory
+            service: Name of a service
+            principal: The name of the role (principal) whose permissions need to be deleted.
+        """
+        urlparams = urllib.urlencode({'principal': principal, 'f': 'json'})
+        folder = self.__process_folder_string(folder)
+        status_url = "services/" + folder + service + "/permissions/clean?{}".format(urlparams)
+        params = {}
+        permisions_data = self.__request_from_server(status_url, params, method='POST')
+
+        if not self.__assert_json_success(permisions_data):
+            raise MyError.MyError(
+                "Error while removing permissions information for {} to {}.".format(
                     service, principal))
 
     def isServiceRunning(self, folder, service):
